@@ -5,11 +5,13 @@ labels on Bokeh plot axes.
 from __future__ import absolute_import
 
 from .tickers import Ticker
-from ..plot_object import PlotObject
-from ..properties import Bool, Int, String, Enum, Auto, List, Dict, Either, Instance
-from ..enums import DatetimeUnits, RoundingFunction, NumeralLanguage
+from ..model import Model
+from ..core.properties import abstract
+from ..core.properties import Bool, Int, String, Enum, Auto, List, Dict, Either, Instance
+from ..core.enums import DatetimeUnits, RoundingFunction, NumeralLanguage
 
-class TickFormatter(PlotObject):
+@abstract
+class TickFormatter(Model):
     """ A base class for all tick formatter types. ``TickFormatter`` is
     not generally useful to instantiate on its own.
 
@@ -134,7 +136,7 @@ class PrintfTickFormatter(TickFormatter):
     """ Tick formatter based on a printf-style format string. """
 
     format = String("%s", help="""
-    The numer format, as defined as follows: the placeholder in the format
+    The number format, as defined as follows: the placeholder in the format
     string is marked by % and is followed by one or more of these elements,
     in this order:
 
@@ -144,7 +146,7 @@ class PrintfTickFormatter(TickFormatter):
 
     * An optional padding specifier
         Specifies what (if any) character to use for padding. Possible values
-        are 0 or any other character precedeed by a ``'`` (single quote). The
+        are 0 or any other character preceded by a ``'`` (single quote). The
         default is to pad with spaces.
 
     * An optional ``-`` sign
@@ -233,7 +235,7 @@ class DatetimeTickFormatter(TickFormatter):
         claim that `timezone`_ makes to support "the full compliment
         of GNU date format specifiers." However, this claim has not
         been tested exhaustively against this list. If you find formats
-        that do not function as expected, please submit a `github issue`,
+        that do not function as expected, please submit a `github issue`_,
         so that the documentation can be updated appropriately.
 
     %a
@@ -270,6 +272,11 @@ class DatetimeTickFormatter(TickFormatter):
         Like %d, the day of the month as a decimal number, but a
         leading zero is replaced by a space.
 
+    %f
+        Microsecond as a decimal number, zero-padded on the left (range
+        000000-999999). This is an extension to the set of directives
+        available to `timezone`_.
+
     %F
         Equivalent to %Y-%m-%d (the ISO 8601 date format).
 
@@ -315,6 +322,13 @@ class DatetimeTickFormatter(TickFormatter):
         A newline character. Bokeh text does not currently support
         newline characters.
 
+    %N
+        Nanosecond as a decimal number, zero-padded on the left (range
+        000000000-999999999). Supports a padding width specifier, i.e.
+        %3N displays 3 leftmost digits. However, this is only accurate
+        to the millisecond level of precision due to limitations of
+        `timezone`_.
+
     %p
         Either "AM" or "PM" according to the given time value, or the
         corresponding strings for the current locale.  Noon is treated
