@@ -4,27 +4,30 @@
 from __future__ import absolute_import
 
 from six import string_types
+import warnings
 
-from ..enums import Location
-from ..mixins import LineProps, TextProps
-from ..plot_object import PlotObject
-from ..properties import Bool, Int, String, Color, Enum, Auto, Instance, Either, List, Dict, Include
-from ..query import find
+from ..core.query import find
+from ..core import validation
+from ..core.validation.warnings import (MISSING_RENDERERS, NO_DATA_RENDERERS,
+    EMPTY_LAYOUT, MALFORMED_CATEGORY_LABEL)
+from ..core.enums import Location
+from ..core.property_mixins import LineProps, TextProps, FillProps
+from ..model import Model
+from ..core.properties import (Bool, Int, String, Enum, Auto, Instance, Either,
+    List, Dict, Include, Override)
 from ..util.string import nice_join
-from ..validation.warnings import MISSING_RENDERERS, NO_GLYPH_RENDERERS, EMPTY_LAYOUT
-from ..validation.errors import REQUIRED_RANGE
-from .. import validation
+from ..core.validation.errors import REQUIRED_RANGE
 
 from .glyphs import Glyph
-from .ranges import Range, Range1d
-from .renderers import Renderer, GlyphRenderer
+from .ranges import Range, Range1d, FactorRange
+from .renderers import Renderer, GlyphRenderer, DataRenderer, TileRenderer, DynamicImageRenderer
 from .sources import DataSource, ColumnDataSource
 from .tools import Tool, ToolEvents
-from .widget import Widget
+from .component import Component
 
 def _select_helper(args, kwargs):
     """
-    Allow fexible selector syntax.
+    Allow flexible selector syntax.
     Returns:
         a dict
     """
@@ -43,7 +46,7 @@ def _select_helper(args, kwargs):
             selector = arg
         elif isinstance(arg, string_types):
             selector = dict(name=arg)
-        elif issubclass(arg, PlotObject):
+        elif issubclass(arg, Model):
             selector = {"type" : arg}
         else:
             raise RuntimeError("Selector must be a dictionary, string or plot object.")
@@ -52,29 +55,12 @@ def _select_helper(args, kwargs):
         selector = kwargs
     return selector
 
+class LayoutBox(Model):
+    ''' Represents an **on-canvas** layout.
 
-class PlotContext(PlotObject):
-    """ A container for multiple plot objects.
+    '''
 
-    ``PlotContext`` objects are a source of confusion. Their purpose
-    is to collect together different top-level objects (e.g., ``Plot``
-    or layout widgets). The reason for this is that different plots may
-    need to share ranges or data sources between them. A ``PlotContext``
-    is a container in which such sharing can occur between the contained
-    objects.
-    """
-
-    children = List(Instance(PlotObject), help="""
-    A list of top level objects in this ``PlotContext`` container.
-    """)
-
-# TODO (bev) : is this used anywhere?
-class PlotList(PlotContext):
-    # just like plot context, except plot context has special meaning
-    # everywhere, so plotlist is the generic one
-    pass
-
-class Plot(Widget):
+class Plot(Component):
     """ Model representing a plot, containing glyphs, guides, annotations.
 
     """
@@ -82,6 +68,13 @@ class Plot(Widget):
     def __init__(self, **kwargs):
         if "tool_events" not in kwargs:
             kwargs["tool_events"] = ToolEvents()
+
+        if "border_fill" in kwargs and "border_fill_color" in kwargs:
+            raise ValueError("Conflicting properties set on plot: border_fill, border_fill_color.")
+
+        if "background_fill" in kwargs and "background_fill_color" in kwargs:
+            raise ValueError("Conflicting properties set on plot: background_fill, background_fill_color.")
+
         super(Plot, self).__init__(**kwargs)
 
     def select(self, *args, **kwargs):
@@ -105,13 +98,13 @@ class Plot(Widget):
             name (str) : the name to query on
 
         Also queries on just type can be made simply by supplying the
-        ``PlotObject`` subclass as the single parameter:
+        ``Model`` subclass as the single parameter:
 
         Args:
-            type (PlotObject) : the type to query on
+            type (Model) : the type to query on
 
         Returns:
-            seq[PlotObject]
+            seq[Model]
 
         Examples:
 
@@ -134,7 +127,7 @@ class Plot(Widget):
         selector = _select_helper(args, kwargs)
 
         # Want to pass selector that is a dictionary
-        from ..plotting_helpers import _list_attr_splat
+        from ..plotting.helpers import _list_attr_splat
         return _list_attr_splat(find(self.references(), selector, {'plot': self}))
 
     def row(self, row, gridplot):
@@ -208,12 +201,14 @@ class Plot(Widget):
             if tool.plot is not None:
                 raise ValueError("tool %s to be added already has 'plot' attribute set" % tool)
             tool.plot = self
+            if hasattr(tool, 'overlay'):
+                self.renderers.append(tool.overlay)
             self.tools.append(tool)
 
     def add_glyph(self, source_or_glyph, glyph=None, **kw):
         ''' Adds a glyph to the plot with associated data sources and ranges.
 
-        This function will take care of creating and configurinf a Glyph object,
+        This function will take care of creating and configuring a Glyph object,
         and then add it to the plot's list of renderers.
 
         Args:
@@ -226,7 +221,7 @@ class Plot(Widget):
             Glyph initializer.
 
         Returns:
-            glyph : Glyph
+            Glyph
 
         '''
         if glyph is not None:
@@ -244,6 +239,40 @@ class Plot(Widget):
         self.renderers.append(g)
         return g
 
+    def add_tile(self, tile_source, **kw):
+        '''Adds new TileRenderer into the Plot.renderers
+
+        Args:
+            tile_source (TileSource) : a tile source instance which contain tileset configuration
+
+        Keyword Arguments:
+            Additional keyword arguments are passed on as-is to the tile renderer
+
+        Returns:
+            TileRenderer : TileRenderer
+
+        '''
+        tile_renderer = TileRenderer(tile_source=tile_source, **kw)
+        self.renderers.append(tile_renderer)
+        return tile_renderer
+
+    def add_dynamic_image(self, image_source, **kw):
+        '''Adds new DynamicImageRenderer into the Plot.renderers
+
+        Args:
+            image_source (ImageSource) : a image source instance which contain image configuration
+
+        Keyword Arguments:
+            Additional keyword arguments are passed on as-is to the dynamic image renderer
+
+        Returns:
+            DynamicImageRenderer : DynamicImageRenderer
+
+        '''
+        image_renderer = DynamicImageRenderer(image_source=image_source, **kw)
+        self.renderers.append(image_renderer)
+        return image_renderer
+
     @validation.error(REQUIRED_RANGE)
     def _check_required_range(self):
         missing = []
@@ -257,11 +286,35 @@ class Plot(Widget):
         if len(self.renderers) == 0:
             return str(self)
 
-    @validation.warning(NO_GLYPH_RENDERERS)
-    def _check_no_glyph_renderers(self):
-        if len(self.select(GlyphRenderer)) == 0:
+    @validation.warning(NO_DATA_RENDERERS)
+    def _check_no_data_renderers(self):
+        if len(self.select(DataRenderer)) == 0:
             return str(self)
 
+    @validation.warning(MALFORMED_CATEGORY_LABEL)
+    def _check_colon_in_category_label(self):
+        if not self.x_range: return
+        if not self.y_range: return
+
+        broken = []
+
+        for range_name in ['x_range', 'y_range']:
+            category_range = getattr(self, range_name)
+            if not isinstance(category_range, FactorRange): continue
+
+            for value in category_range.factors:
+                if not isinstance(value, string_types): break
+                if ':' in value:
+                    broken.append((range_name, value))
+                    break
+
+        if broken:
+            field_msg = ' '.join('[range:%s] [first_value: %s]' % (field, value)
+                                 for field, value in broken)
+            return '%s [renderer: %s]' % (field_msg, self)
+
+    __deprecated_attributes__ = ('background_fill', 'border_fill')
+
     x_range = Instance(Range, help="""
     The (default) data range of the horizontal dimension of the plot.
     """)
@@ -300,6 +353,15 @@ class Plot(Widget):
     This is useful for adding additional axes.
     """)
 
+    hidpi = Bool(default=True, help="""
+    Whether to use HiDPI mode when available.
+    """)
+
+    title_standoff = Int(default=8, help="""
+    How far (in screen units) to place a title away from the central
+    plot region.
+    """)
+
     title = String('', help="""
     A title for the plot.
     """)
@@ -308,10 +370,18 @@ class Plot(Widget):
     The %s for the plot title.
     """)
 
+    title_text_align = Override(default='center')
+
+    title_text_baseline = Override(default='alphabetic')
+
+    title_text_font_size = Override(default={ 'value' : '20pt' })
+
     outline_props = Include(LineProps, help="""
     The %s for the plot border outline.
     """)
 
+    outline_line_color = Override(default="#aaaaaa")
+
     renderers = List(Instance(Renderer), help="""
     A list of all renderers for this plot, including guides and annotations
     in addition to glyphs and markers.
@@ -337,7 +407,9 @@ class Plot(Widget):
     A list of renderers to occupy the area to the right of the plot.
     """)
 
-    above = List(Instance(Renderer), help="""
+    # TODO (bev) LayoutBox here is a temporary workaround to the fact that
+    # plot titles are not proper renderers
+    above = List(Either(Instance(Renderer), Instance(LayoutBox)), help="""
     A list of renderers to occupy the area above of the plot.
     """)
 
@@ -375,14 +447,54 @@ class Plot(Widget):
 
     """)
 
-    background_fill = Color("white", help="""
+    @property
+    def background_fill(self):
+        warnings.warn(
+            """
+            Plot property 'background_fill' was deprecated in Bokeh
+            0.11.0 and will be removed. Use 'background_fill_color' instead.
+            """)
+        return self.background_fill_color
 
+    @background_fill.setter
+    def background_fill(self, color):
+        warnings.warn(
+            """
+            Plot property 'background_fill' was deprecated in Bokeh
+            0.11.0 and will be removed. Use 'background_fill_color' instead.
+            """)
+        self.background_fill_color = color
+
+    @property
+    def border_fill(self):
+        warnings.warn(
+            """
+            Plot property 'border_fill' was deprecated in Bokeh 0.11.0 and
+            will be removed. Use 'border_fill_color' instead.
+            """)
+        return self.border_fill_color
+
+    @border_fill.setter
+    def border_fill(self, color):
+        warnings.warn(
+            """
+            Plot property 'border_fill' was deprecated in Bokeh 0.11.0 and
+            will be removed. Use 'border_fill_color' instead.
+            """)
+        self.border_fill_color = color
+
+    background_props = Include(FillProps, help="""
+    The %s for the plot background style.
     """)
 
-    border_fill = Color("white", help="""
+    background_fill_color = Override(default='#ffffff')
 
+    border_props = Include(FillProps, help="""
+    The %s for the plot border style.
     """)
 
+    border_fill_color = Override(default='#ffffff')
+
     min_border_top = Int(50, help="""
     Minimum size in pixels of the padding region above the top of the
     central plot region.
@@ -434,6 +546,7 @@ class Plot(Widget):
     be made equal (the left or right padding amount, whichever is larger).
     """)
 
+
     v_symmetry = Bool(False, help="""
     Whether the total vertical padding on both sides of the plot will
     be made equal (the top or bottom padding amount, whichever is larger).
@@ -461,7 +574,23 @@ class Plot(Widget):
     level-of-detail mode is disabled.
     """)
 
-class GridPlot(Plot):
+    webgl = Bool(False, help="""
+    Whether WebGL is enabled for this plot. If True, the glyphs that
+    support this will render via WebGL instead of the 2D canvas.
+    """)
+
+    responsive = Bool(False, help="""
+    If True, the plot will automatically resize based on the size of its container. The
+    aspect ratio of the plot will be preserved, but ``plot_width`` and ``plot_height`` will
+    act only to set the initial aspect ratio.
+    .. warning::
+
+       The responsive setting is known not to work with HBox layout and may not work
+       in combination with other widgets or layouts.
+    """)
+
+
+class GridPlot(Component):
     """ A 2D grid of plots rendered on separate canvases in an HTML table.
 
     """
@@ -473,8 +602,9 @@ class GridPlot(Plot):
     @validation.warning(MISSING_RENDERERS)
     def _check_missing_renderers(self):
         pass
-    @validation.warning(NO_GLYPH_RENDERERS)
-    def _check_no_glyph_renderers(self):
+
+    @validation.warning(NO_DATA_RENDERERS)
+    def _check_no_data_renderers(self):
         pass
 
     @validation.warning(EMPTY_LAYOUT)
@@ -483,7 +613,7 @@ class GridPlot(Plot):
         if not list(chain(self.children)):
             return str(self)
 
-    children = List(List(Instance(Plot)), help="""
+    children = List(List(Instance(Plot)), default=[[]], help="""
     An array of plots to display in a grid, given as a list of lists of
     Plot objects. To leave a position in the grid empty, pass None for
     that position in the ``children`` list.
@@ -493,19 +623,23 @@ class GridPlot(Plot):
     Distance (in pixels) between adjacent plots.
     """)
 
+    toolbar_location = Enum(Location, default="left", help="""
+    Where the toolbar will be located. If set to None, no toolbar
+    will be attached to the plot.
+    """)
+
     def select(self, *args, **kwargs):
         ''' Query this object and all of its references for objects that
-        match the given selector. See Plot.select for detailed usage infomation.
+        match the given selector. See Plot.select for detailed usage information.
 
         Returns:
-            seq[PlotObject]
-
+            seq[Model]
         '''
 
         selector = _select_helper(args, kwargs)
 
         # Want to pass selector that is a dictionary
-        from ..plotting_helpers import _list_attr_splat
+        from ..plotting.helpers import _list_attr_splat
         return _list_attr_splat(find(self.references(), selector, {'gridplot': self}))
 
     def column(self, col):
