@@ -1,4 +1,4 @@
-var ClientConnection, ClientSession, DEFAULT_SERVER_WEBSOCKET_URL, DEFAULT_SESSION_ID, Document, HasProperties, Message, ModelChangedEvent, Promise, RootAddedEvent, RootRemovedEvent, _, logger, message_handlers, pull_session, ref;
+var ClientConnection, ClientSession, DEFAULT_SERVER_WEBSOCKET_URL, DEFAULT_SESSION_ID, Document, HasProps, Message, ModelChangedEvent, Promise, RootAddedEvent, RootRemovedEvent, _, logger, message_handlers, pull_session, ref;
 
 _ = require("underscore");
 
@@ -8,7 +8,7 @@ logger = require("./logging").logger;
 
 ref = require("./document"), Document = ref.Document, ModelChangedEvent = ref.ModelChangedEvent, RootAddedEvent = ref.RootAddedEvent, RootRemovedEvent = ref.RootRemovedEvent;
 
-HasProperties = require("./has_properties");
+HasProps = require("./has_props");
 
 DEFAULT_SERVER_WEBSOCKET_URL = "ws://localhost:5006/ws";
 
@@ -353,7 +353,7 @@ ClientConnection = (function() {
       return this._on_message_unchecked(event);
     } catch (error1) {
       e = error1;
-      return logger.error("Error handling message ", e, event);
+      return logger.error("Error handling message: " + e + ", " + event);
     }
   };
 
@@ -507,7 +507,7 @@ ClientSession = (function() {
         event_json = ref1[i];
         if (event_json['kind'] === 'ModelChanged' && event_json['model']['id'] === event.model.id && event_json['attr'] === event.attr) {
           patch_new = event_json['new'];
-          if (event.new_ instanceof HasProperties) {
+          if (event.new_ instanceof HasProps) {
             if (typeof patch_new === 'object' && 'id' in patch_new && patch_new['id'] === event.new_.id) {
               return true;
             }
