@@ -1,4 +1,4 @@
-var Collections, DEFAULT_TITLE, Document, DocumentChangedEvent, HasProperties, ModelChangedEvent, RootAddedEvent, RootRemovedEvent, TitleChangedEvent, _, _MultiValuedDict, logger,
+var Collections, DEFAULT_TITLE, Document, DocumentChangedEvent, HasProps, ModelChangedEvent, RootAddedEvent, RootRemovedEvent, TitleChangedEvent, _, _MultiValuedDict, logger,
   extend = function(child, parent) { for (var key in parent) { if (hasProp.call(parent, key)) child[key] = parent[key]; } function ctor() { this.constructor = child; } ctor.prototype = parent.prototype; child.prototype = new ctor(); child.__super__ = parent.prototype; return child; },
   hasProp = {}.hasOwnProperty,
   indexOf = [].indexOf || function(item) { for (var i = 0, l = this.length; i < l; i++) { if (i in this && this[i] === item) return i; } return -1; };
@@ -7,7 +7,7 @@ _ = require("underscore");
 
 logger = require("./logging").logger;
 
-HasProperties = require("./has_properties");
+HasProps = require("./has_props");
 
 Collections = require("./base").Collections;
 
@@ -347,7 +347,7 @@ Document = (function() {
   Document._resolve_refs = function(value, old_references, new_references) {
     var resolve_array, resolve_dict, resolve_ref;
     resolve_ref = function(v) {
-      if (HasProperties._is_ref(v)) {
+      if (HasProps._is_ref(v)) {
         if (v['id'] in old_references) {
           return old_references[v['id']];
         } else if (v['id'] in new_references) {
@@ -401,7 +401,7 @@ Document = (function() {
       already_started = {};
       foreach_value = function(v, f) {
         var a, attrs, e, k, l, len1, ref1, results, results1, same_as_v;
-        if (v instanceof HasProperties) {
+        if (v instanceof HasProps) {
           if (!(v.id in already_started) && v.id in items) {
             already_started[v.id] = true;
             ref1 = items[v.id], same_as_v = ref1[0], attrs = ref1[1], was_new = ref1[2];
@@ -461,7 +461,7 @@ Document = (function() {
       'attr': key,
       'new': new_value
     };
-    HasProperties._json_record_references(doc, new_value, value_refs, true);
+    HasProps._json_record_references(doc, new_value, value_refs, true);
     return event;
   };
 
@@ -644,9 +644,9 @@ Document = (function() {
           throw new Error("'id' field should never change, whatever code just set it is wrong");
         }
         value = event.new_;
-        value_json = HasProperties._value_to_json('new_', value, event.model);
+        value_json = HasProps._value_to_json('new_', value, event.model);
         value_refs = {};
-        HasProperties._value_record_references(value, value_refs, true);
+        HasProps._value_record_references(value, value_refs, true);
         if (event.model.id in value_refs && event.model !== value) {
           delete value_refs[event.model.id];
         }
@@ -661,7 +661,7 @@ Document = (function() {
         };
         json_events.push(json_event);
       } else if (event instanceof RootAddedEvent) {
-        HasProperties._value_record_references(event.model, references, true);
+        HasProps._value_record_references(event.model, references, true);
         json_event = {
           'kind': 'RootAdded',
           'model': event.model.ref()
@@ -692,7 +692,7 @@ Document = (function() {
   };
 
   Document.prototype.apply_json_patch = function(patch) {
-    var attr, event_json, events_json, id, j, l, len, len1, model_id, new_references, obj1, old_references, patched_id, patched_obj, references, references_json, results, root_id, root_obj, value;
+    var attr, column_source, column_source_id, data, event_json, events_json, id, j, l, len, len1, model_id, new_references, obj1, old_references, patched_id, patched_obj, references, references_json, results, rollover, root_id, root_obj, value;
     references_json = patch['references'];
     events_json = patch['events'];
     references = Document._instantiate_references_json(references_json, this._all_models);
@@ -735,6 +735,15 @@ Document = (function() {
           obj1["" + attr] = value,
           obj1
         )));
+      } else if (event_json['kind'] === 'ColumnsStreamed') {
+        column_source_id = event_json['column_source']['id'];
+        if (!(column_source_id in this._all_models)) {
+          throw new Error("Cannot stream to " + column_source_id + " which is not in the document");
+        }
+        column_source = this._all_models[column_source_id];
+        data = event_json['data'];
+        rollover = event_json['rollover'];
+        results.push(column_source.stream(data, rollover));
       } else if (event_json['kind'] === 'RootAdded') {
         root_id = event_json['model']['id'];
         root_obj = references[root_id];
