@@ -2,8 +2,15 @@ from __future__ import absolute_import
 
 import unittest
 
+import os
+
 import bokeh.resources as resources
-from bokeh.resources import _get_cdn_urls
+from bokeh.resources import _get_cdn_urls, websocket_url_for_server_url
+
+
+# if BOKEH_RESOURCES is set many tests in this file fail
+if os.environ.get("BOKEH_RESOURCES"):
+    raise RuntimeError("Cannot run the unit tests with BOKEH_RESOURCES set")
 
 WRAPPER = """Bokeh.$(function() {
     foo
@@ -34,7 +41,7 @@ def test_js_resources_inline_has_no_css_resources():
     assert r.mode == "inline"
     assert r.dev is False
 
-    assert len(r.js_raw) == 2
+    assert len(r.js_raw) == 4
     assert r.js_raw[-1] == DEFAULT_LOG_JS_RAW
     assert hasattr(r, 'css_raw') is False
     assert r.messages == []
@@ -52,13 +59,24 @@ def test_inline_css_resources():
     assert r.mode == "inline"
     assert r.dev is False
 
-    assert len(r.css_raw) == 1
+    assert len(r.css_raw) == 2
     assert hasattr(r, 'js_raw') is False
     assert r.messages == []
 
 
 class TestResources(unittest.TestCase):
 
+    def test_websocket_url(self):
+        self.assertEqual("ws://example.com:4000/ws", websocket_url_for_server_url("http://example.com:4000"))
+        # with trailing / on original url
+        self.assertEqual("ws://example.com:4000/ws", websocket_url_for_server_url("http://example.com:4000/"))
+        # with https
+        self.assertEqual("wss://example.com:4000/ws", websocket_url_for_server_url("https://example.com:4000"))
+        # with a path
+        self.assertEqual("wss://example.com:4000/bar/ws", websocket_url_for_server_url("https://example.com:4000/bar"))
+        # with path with trailing slash
+        self.assertEqual("wss://example.com:4000/bar/ws", websocket_url_for_server_url("https://example.com:4000/bar/"))
+
     def test_basic(self):
         r = resources.Resources()
         self.assertEqual(r.mode, "inline")
@@ -81,15 +99,15 @@ class TestResources(unittest.TestCase):
         self.assertEqual(r.mode, "inline")
         self.assertEqual(r.dev, False)
 
-        self.assertEqual(len(r.js_raw), 2)
+        self.assertEqual(len(r.js_raw), 4)
         self.assertEqual(r.js_raw[-1], DEFAULT_LOG_JS_RAW)
-        self.assertEqual(len(r.css_raw), 1)
+        self.assertEqual(len(r.css_raw), 2)
         self.assertEqual(r.messages, [])
 
     def test_get_cdn_urls(self):
         dev_version = "0.0.1dev"
-        result = _get_cdn_urls(dev_version)
-        url = result['js_files'][0]
+        result = _get_cdn_urls(["bokeh"], version=dev_version)
+        url = result['urls']('js')[0]
         self.assertIn('bokeh/dev', url)
 
     def test_cdn(self):
@@ -124,6 +142,19 @@ class TestResources(unittest.TestCase):
         self.assertEqual(r.css_raw, [])
         self.assertEqual(r.messages, [])
 
+    def test_server_with_versioner(self):
+        def versioner(path):
+            return path + "?v=VERSIONED"
+
+        r = resources.Resources(mode="server", root_url="http://foo/",
+                                path_versioner=versioner)
+
+        self.assertEqual(r.js_files, ['http://foo/static/js/bokeh.min.js?v=VERSIONED',
+                                      'http://foo/static/js/bokeh-widgets.min.js?v=VERSIONED',
+                                      'http://foo/static/js/bokeh-compiler.min.js?v=VERSIONED'])
+        self.assertEqual(r.css_files, ['http://foo/static/css/bokeh.min.css?v=VERSIONED',
+                                       'http://foo/static/css/bokeh-widgets.min.css?v=VERSIONED'])
+
     def test_server_dev(self):
         r = resources.Resources(mode="server-dev")
         self.assertEqual(r.mode, "server")
