@@ -1,13 +1,12 @@
-""" Functions useful for loading Bokeh code and data in IPython notebooks.
+''' Functions useful for loading Bokeh code and data in IPython notebooks.
 
-"""
+'''
 from __future__ import absolute_import
 
 _notebook_loaded = None
 
-
 def load_notebook(resources=None, verbose=False, hide_banner=False):
-    """ Prepare the IPython notebook for displaying Bokeh plots.
+    ''' Prepare the IPython notebook for displaying Bokeh plots.
 
     Args:
         resources (Resource, optional) :
@@ -26,24 +25,21 @@ def load_notebook(resources=None, verbose=False, hide_banner=False):
     Returns:
         None
 
-    """
+    '''
+    html, js = _load_notebook_html(resources, verbose, hide_banner)
+    publish_display_data({'text/html': html})
+    publish_display_data({'application/javascript': js})
+
+def _load_notebook_html(resources=None, verbose=False, hide_banner=False):
     global _notebook_loaded
 
     from .. import __version__
-    from ..resources import INLINE
-    from ..templates import NOTEBOOK_LOAD, JS_RESOURCES, CSS_RESOURCES
+    from ..core.templates import AUTOLOAD_JS, NOTEBOOK_LOAD
+    from ..util.serialization import make_id
+    from ..resources import CDN
 
     if resources is None:
-        resources = INLINE
-
-    bokeh_js = JS_RESOURCES.render(
-        js_raw=resources.js_raw,
-        js_files=resources.js_files,
-    )
-    bokeh_css = CSS_RESOURCES.render(
-        css_raw=resources.css_raw,
-        css_files=resources.css_files,
-    )
+        resources = CDN
 
     if resources.mode == 'inline':
         js_info = 'inline'
@@ -59,22 +55,32 @@ def load_notebook(resources=None, verbose=False, hide_banner=False):
 
     _notebook_loaded = resources
 
-    html = NOTEBOOK_LOAD.render(
-        bokeh_js=bokeh_js,
-        bokeh_css=bokeh_css,
-        logo_url=resources.logo_url,
-        verbose=verbose,
-        js_info=js_info,
-        css_info=css_info,
-        bokeh_version=__version__,
-        warnings=warnings,
-        hide_banner=hide_banner,
-    )
-    publish_display_data({'text/html': html})
+    element_id = make_id()
 
+    html = NOTEBOOK_LOAD.render(
+        element_id    = element_id,
+        logo_url      = resources.logo_url,
+        verbose       = verbose,
+        js_info       = js_info,
+        css_info      = css_info,
+        bokeh_version = __version__,
+        warnings      = warnings,
+        hide_banner   = hide_banner,
+    )
+
+    finalize_js = """Bokeh.$("#%s").text("BokehJS successfully loaded");""" % element_id
+
+    js = AUTOLOAD_JS.render(
+        js_urls  = resources.js_files,
+        css_urls = resources.css_files,
+        js_raw   = resources.js_raw + [finalize_js],
+        css_raw  = resources.css_raw_str,
+    )
+
+    return html, js
 
 def publish_display_data(data, source='bokeh'):
-    """ Compatibility wrapper for IPython ``publish_display_data``
+    ''' Compatibility wrapper for IPython ``publish_display_data``
 
     Later versions of IPython remove the ``source`` (first) argument. This
     function insulates Bokeh library code from this change.
@@ -84,9 +90,24 @@ def publish_display_data(data, source='bokeh'):
         data (dict) : the data dict to pass to ``publish_display_data``
             Typically has the form ``{'text/html': html}``
 
-    """
+    '''
     import IPython.core.displaypub as displaypub
     try:
         displaypub.publish_display_data(source, data)
     except TypeError:
         displaypub.publish_display_data(data)
+
+def get_comms(target_name):
+    ''' Create a Jupyter comms object for a specific target, that can
+    be used to update Bokeh documents in the notebook.
+
+    Args:
+        target_name (str) : the target name the Comms object should connect to
+
+    Returns
+        Jupyter Comms
+
+    '''
+    from ipykernel.comm import Comm
+    return Comm(target_name=target_name, data={})
+
