@@ -1,17 +1,17 @@
 
-from bokeh.io import vform
-from bokeh.plotting import figure, hplot, output_file, show, ColumnDataSource
-from bokeh.models import CustomJS, Slider
-
 import numpy as np
 
+from bokeh.io import vform
+from bokeh.models import CustomJS, Slider
+from bokeh.plotting import figure, hplot, output_file, show, ColumnDataSource
+
 x = np.linspace(0, 10, 500)
 y = np.sin(x)
 
 source = ColumnDataSource(data=dict(x=x, y=y))
 
-
 plot = figure(y_range=(-10, 10), plot_width=400, plot_height=400)
+
 plot.line('x', 'y', source=source, line_width=3, line_alpha=0.6)
 
 callback = CustomJS(args=dict(source=source), code="""
@@ -28,16 +28,20 @@ callback = CustomJS(args=dict(source=source), code="""
     source.trigger('change');
 """)
 
-amp_slider = Slider(start=0.1, end=10, value=1, step=.1, title="Amplitude", callback=callback)
+amp_slider = Slider(start=0.1, end=10, value=1, step=.1,
+                    title="Amplitude", callback=callback)
 callback.args["amp"] = amp_slider
 
-freq_slider = Slider(start=0.1, end=10, value=1, step=.1, title="Frequency", callback=callback)
+freq_slider = Slider(start=0.1, end=10, value=1, step=.1,
+                     title="Frequency", callback=callback)
 callback.args["freq"] = freq_slider
 
-phase_slider = Slider(start=0, end=6.4, value=0, step=.1, title="Phase", callback=callback)
+phase_slider = Slider(start=0, end=6.4, value=0, step=.1,
+                      title="Phase", callback=callback)
 callback.args["phase"] = phase_slider
 
-offset_slider = Slider(start=-5, end=5, value=0, step=.1, title="Offset", callback=callback)
+offset_slider = Slider(start=-5, end=5, value=0, step=.1,
+                       title="Offset", callback=callback)
 callback.args["offset"] = offset_slider
 
 layout = hplot(
@@ -45,6 +49,6 @@ layout = hplot(
     vform(amp_slider, freq_slider, phase_slider, offset_slider),
 )
 
-output_file("slider.html")
+output_file("slider.html", title="slider.py example")
 
 show(layout)
